;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;                                                                     ;;;
;;;                     Carnegie Mellon University                      ;;;
;;;                  and Alan W Black and Kevin Lenzo                   ;;;
;;;                      Copyright (c) 1998-2000                        ;;;
;;;                        All Rights Reserved.                         ;;;
;;;                                                                     ;;;
;;; Permission is hereby granted, free of charge, to use and distribute ;;;
;;; this software and its documentation without restriction, including  ;;;
;;; without limitation the rights to use, copy, modify, merge, publish, ;;;
;;; distribute, sublicense, and/or sell copies of this work, and to     ;;;
;;; permit persons to whom this work is furnished to do so, subject to  ;;;
;;; the following conditions:                                           ;;;
;;;  1. The code must retain the above copyright notice, this list of   ;;;
;;;     conditions and the following disclaimer.                        ;;;
;;;  2. Any modifications must be clearly marked as such.               ;;;
;;;  3. Original authors' names are not deleted.                        ;;;
;;;  4. The authors' names are not used to endorse or promote products  ;;;
;;;     derived from this software without specific prior written       ;;;
;;;     permission.                                                     ;;;
;;;                                                                     ;;;
;;; CARNEGIE MELLON UNIVERSITY AND THE CONTRIBUTORS TO THIS WORK        ;;;
;;; DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING     ;;;
;;; ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT  ;;;
;;; SHALL CARNEGIE MELLON UNIVERSITY NOR THE CONTRIBUTORS BE LIABLE     ;;;
;;; FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES   ;;;
;;; WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN  ;;;
;;; AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,         ;;;
;;; ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF      ;;;
;;; THIS SOFTWARE.                                                      ;;;
;;;                                                                     ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; Phonset for eki_et
;;;

;;;  Feeel free to add new feature values, or new features to this
;;;  list to make it more appropriate to your language

;; This is where it'll fall over if you haven't defined a 
;; a phoneset yet, if you have, delete this, if you haven't
;; define one then delete this error message


(defPhoneSet
  eki_et
  ;;;  Phone Features
  (;; 

   (vc + - 0)               ;; vowel/consonant
   (vlng s l 0)             ;; vowel length
   (vheight 1 2 3 0)        ;; vowel height
   (vfront 1 2 3 0)         ;; vowel frontness
   (vrnd + - 0)             ;; vowel rounding
   (ctype s f a n l r 0)    ;; articulation type
   (cplace l a p b d v g 0) ;; articulation place
   (cvox + - 0)             ;; consonant voicing
   (nasaal + - 0)          ;; nasal
   (klusiil + - 0)         ;; plosive
   (frikatiiv + - 0)       ;; fricative
   (sibilant + - 0)       ;; sibilant
   (liquid + - 0)          ;; liquid
   (lateraal + - 0)        ;; lateral
   (poolvokaal + - 0)     ;; semivowel
   (clng s l 0)             ;; consonant length
   (cpalat + - 0)        ;; Lips Alveolar Rest 0

   )
  (

   (a   +   s   3   3   -   0   0   0 0 0 0 0 0 0 0 0 0 ) 
   (e   +   s   2   1   -   0   0   0 0 0 0 0 0 0 0 0 0 )
   (i   +   s   1   1   -   0   0   0 0 0 0 0 0 0 0 0 0 )
   (o   +   s   2   3   +   0   0   0 0 0 0 0 0 0 0 0 0 )
   (u   +   s   1   3   +   0   0   0 0 0 0 0 0 0 0 0 0 )
   (q   +   s   2   3   -   0   0   0 0 0 0 0 0 0 0 0 0 ) ;; õ { 
   (x   +   s   3   1   -   0   0   0 0 0 0 0 0 0 0 0 0 ) ;; ä 
   (c   +   s   2   1   +   0   0   0 0 0 0 0 0 0 0 0 0 ) ;; ö
   (y   +   s   1   1   +   0   0   0 0 0 0 0 0 0 0 0 0 ) ;; ü



; nz (N:) on lihtsalt puudu
   (b   -   0   0   0   0   s   l   + - + - - - - - s - )
   (d   -   0   0   0   0   s   a   + - + - - - - - s - )
   (g   -   0   0   0   0   s   v   + - + - - - - - s - ) 
   
   (f   -   0   0   0   0   f   b   - - - + - - - - s - )


   (h   -   0   0   0   0   f   g   - - - + - - - - s - ) 


   (j   -   0   0   0   0   r   p   + - - - - - - + s - )

   (k   -   0   0   0   0   s   v   - - + - - - - - s - ) 


   (l   -   0   0   0   0   l   a   + - - - - + + - s - )


   (m   -   0   0   0   0   n   l   + + - - - - - - s - )


   (n   -   0   0   0   0   n   a   + + - - - - - - s - )   

   (p   -   0   0   0   0   s   l   - - + - - - - - s - )


   (r   -   0   0   0   0   r   a   + - - - - + - - s - )


   (s   -   0   0   0   0   f   a   - - - + + - - - s - )



   (sh  -   0   0   0   0   f   p   - - - + + - - - s - )



   (t   -   0   0   0   0   s   a   - - + - - - - - s - )

   (v   -   0   0   0   0   f   b   + - - + - - - - s - )


   (w   -   0   0   0   0   r   p   + - - - - - - + l - )
   (ng  -   0   0   0   0   n   v   + + - - - - - - l - )
   (pau  -  0   0   0   0   0   0   0 0 0 0 0 0 0 0 0 0 )
))


(PhoneSet.silences '(pau))

(define (eki_et_tonu::select_phoneset)
  "(eki_et_tonu::select_phoneset)
Set up phone set for eki_et."
  (Parameter.set 'PhoneSet 'eki_et)
  (PhoneSet.select 'eki_et)
)

(define (eki_et_tonu::reset_phoneset)
  "(eki_et_tonu::reset_phoneset)
Reset phone set for eki_et."
  t
)

(provide 'eki_et_tonu_phoneset)


