;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;                                                                     ;;;
;;;                     Carnegie Mellon University                      ;;;
;;;                  and Alan W Black and Kevin Lenzo                   ;;;
;;;                      Copyright (c) 1998-2000                        ;;;
;;;                        All Rights Reserved.                         ;;;
;;;                                                                     ;;;
;;; Permission is hereby granted, free of charge, to use and distribute ;;;
;;; this software and its documentation without restriction, including  ;;;
;;; without limitation the rights to use, copy, modify, merge, publish, ;;;
;;; distribute, sublicense, and/or sell copies of this work, and to     ;;;
;;; permit persons to whom this work is furnished to do so, subject to  ;;;
;;; the following conditions:                                           ;;;
;;;  1. The code must retain the above copyright notice, this list of   ;;;
;;;     conditions and the following disclaimer.                        ;;;
;;;  2. Any modifications must be clearly marked as such.               ;;;
;;;  3. Original authors' names are not deleted.                        ;;;
;;;  4. The authors' names are not used to endorse or promote products  ;;;
;;;     derived from this software without specific prior written       ;;;
;;;     permission.                                                     ;;;
;;;                                                                     ;;;
;;; CARNEGIE MELLON UNIVERSITY AND THE CONTRIBUTORS TO THIS WORK        ;;;
;;; DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING     ;;;
;;; ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT  ;;;
;;; SHALL CARNEGIE MELLON UNIVERSITY NOR THE CONTRIBUTORS BE LIABLE     ;;;
;;; FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES   ;;;
;;; WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN  ;;;
;;; AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,         ;;;
;;; ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF      ;;;
;;; THIS SOFTWARE.                                                      ;;;
;;;                                                                     ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; Tokenizer for et
;;;
;;;  To share this among voices you need to promote this file to
;;;  to say festival/lib/eki_et/ so others can use it.
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;; Load any other required files


;; Punctuation for the particular language
;(set! eki_et_tonu::token.punctuation "\"'`.,;!?(){}[]")
(set! eki_et_tonu::token.punctuation "\"`.,;:!?(){}[]")

(set! eki_et_tonu::token.prepunctuation ",.\";:`({[")
(set! eki_et_tonu::token.whitespace " \t\n\r")
(set! eki_et_tonu::token.singlecharsymbols ":#$%&*+/<=>@^_`~|\\")


;(set! eki_et_tonu::token.prepunctuation "-,.\"'`({[")
;(set! eki_et_tonu::token.whitespace " \t\n\r")
;(set! eki_et_tonu::token.singlecharsymbols "\"#$%&'*+-/<=>@^_`~|\\")


;(define (concat list)
;    "convert list into string"
;    (cond ((null list) "")
;	  (t (string-append (car list) (concat (cdr list))))))


(define (eki_et_tonu::token_to_words token name)
  "(eki_et_tonu::token_to_words token name)
Specific token to word rules for the voice eki_et_tonu.  Returns a list
of words that expand given token with name."


(if (eq? festvox_debug 1)	 (print (format nil "[token sisse: %s]" name)))

(if (string-matches name "\\(II?I?\\|IV\\|VI?I?I?\\|IX\\|X[VIX]*\\)")
(begin 
	(set! name (tok_roman_to_numstring name))
	(item.set_feat token "punc" "."))
	(set! name name))
	
(set! j 0)
(if (string-matches (item.feat token "punc") "\\.") 
	(set! j 1))	
	

(set! name (car (eki_et_lower name)))
;(print name)


(cond
	((not (equal? (assoc_string name lyhendite_loend) nil)) ;Kui on lhend - siis olgu
		(cdr (assoc_string name lyhendite_loend)))
	((string-matches name ".*[0-9].*")(set! name (eki_et_estonian_numbers name j token)))	
	((string-matches name "^\\(.*\-\\)?[BCDFGHJKLMNPQRSTVWXZbcdfghjklmnpqrstvwxz]+\\(\-.*\\)?$")
			(symbolexplode name))
	
   (t 
   (list name)
))); kui reegleid pole







(define (tok_roman_to_numstring roman)
  "(tok_roman_to_numstring ROMAN)
Takes a string of roman numerals and converts it to a number and
then returns the printed string of that.  Only deals with numbers up to 50."
  (let ((val 0) (chars (symbolexplode roman)))
    (while chars
     (cond
      ((equal? (car chars) 'X)
       (set! val (+ 10 val)))
      ((equal? (car chars) 'V)
       (set! val (+ 5 val)))
      ((equal? (car chars) 'I)
       (cond
	((equal? (car (cdr chars)) 'V)
	 (set! val (+ 4 val))
	 (set! chars (cdr chars)))
	((equal? (car (cdr chars)) 'X)
	 (set! val (+ 9 val))
	 (set! chars (cdr chars)))
	(t
	 (set! val (+ 1 val))))))
     (set! chars (cdr chars)))
    (format nil "%d" val)))




(define (eki_et_tonu::select_tokenizer)
  "(eki_et_tonu::select_tokenizer)
Set up tokenizer for et."
  (Parameter.set 'Language 'eki_et)  
	(set! token.punctuation eki_et_tonu::token.punctuation)
  (set! token.prepunctuation eki_et_tonu::token.prepunctuation)
  (set! token.whitespace eki_et_tonu::token.whitespace)
  (set! token.singlecharsymbols eki_et_tonu::token.singlecharsymbols)
  (set! token_to_words eki_et_tonu::token_to_words)
)

(define (eki_et_tonu::reset_tokenizer)
  "(eki_et_tonu::reset_tokenizer)
Reset any globals modified for this voice.  Called by 
(eki_et_tonu::voice_reset)."
  ;; None

  t
)

(provide 'eki_et_tonu_tokenizer)
